@@ -74,18 +74,18 @@ class EnterpriseLearnerEnrollment(models.Model):
     enterprise_enrollment_id = models.PositiveIntegerField(primary_key=True)
     enrollment_id = models.PositiveIntegerField(null=True)
     is_consent_granted = models.BooleanField(default=False)
-    paid_by = models.CharField(max_length=128, null=True)
+    paid_by = models.CharField(max_length=255, null=True)
     user_current_enrollment_mode = models.CharField(max_length=32)
     enrollment_date = models.DateField()
     unenrollment_date = models.DateField(null=True)
     unenrollment_end_within_date = models.DateField(null=True)
     is_refunded = models.BooleanField(default=None, null=True)
-    seat_delivery_method = models.CharField(max_length=128, null=True)
+    seat_delivery_method = models.CharField(max_length=255, null=True)
     offer_name = models.CharField(max_length=255, null=True)
-    offer_type = models.CharField(max_length=128, null=True)
-    coupon_code = models.CharField(max_length=128, null=True)
-    coupon_name = models.CharField(max_length=128, null=True)
-    contract_id = models.CharField(max_length=128, null=True)
+    offer_type = models.CharField(max_length=255, null=True)
+    coupon_code = models.CharField(max_length=255, null=True)
+    coupon_name = models.CharField(max_length=255, null=True)
+    contract_id = models.CharField(max_length=255, null=True)
     course_list_price = models.FloatField(null=True)
     amount_learner_paid = models.FloatField(null=True)
     course_key = models.CharField(max_length=255, null=False, db_index=True)
@@ -97,14 +97,15 @@ class EnterpriseLearnerEnrollment(models.Model):
     course_duration_weeks = models.PositiveIntegerField(null=True)
     course_max_effort = models.PositiveIntegerField(null=True)
     course_min_effort = models.PositiveIntegerField(null=True)
-    course_primary_program = models.CharField(max_length=128, null=True)
-    course_primary_subject = models.CharField(max_length=128, null=True)
+    course_primary_program = models.CharField(max_length=255, null=True)
+    primary_program_type = models.CharField(max_length=255, null=True)
+    course_primary_subject = models.CharField(max_length=255, null=True)
     has_passed = models.BooleanField(default=False)
     last_activity_date = models.DateField(null=True, db_index=True)
-    progress_status = models.CharField(max_length=128, null=True)
+    progress_status = models.CharField(max_length=255, null=True)
     passed_date = models.DateField(null=True)
     current_grade = models.FloatField(null=True)
-    letter_grade = models.CharField(max_length=32, null=True)
+    letter_grade = models.CharField(max_length=64, null=True)
     enterprise_user = models.ForeignKey(
         'EnterpriseLearner',
         related_name='enrollments',
